# Code of Conduct

## Our Commitment

We are committed to providing a welcoming and professional environment for all contributors and users of xbbg.

## Standards

Examples of behavior that contributes to a positive environment:

* Using welcoming and professional language
* Being respectful of differing viewpoints and experiences
* Gracefully accepting constructive criticism
* Focusing on what is best for the community
* Showing empathy towards other community members

Examples of unacceptable behavior:

* Trolling, insulting or derogatory comments, and personal attacks
* Public or private harassment
* Publishing others' private information without explicit permission
* Other conduct which could reasonably be considered inappropriate in a professional setting

## Responsibilities

Project maintainers are responsible for clarifying the standards of acceptable behavior and are expected to take appropriate and fair corrective action in response to any instances of unacceptable behavior.

Project maintainers have the right and responsibility to remove, edit, or reject comments, commits, code, wiki edits, issues, and other contributions that are not aligned to this Code of Conduct.

## Scope

This Code of Conduct applies within all project spaces, including GitHub repositories, Discord channels, and any other official communication channels.

## Enforcement

Instances of unacceptable behavior may be reported by contacting the project team at alpha.xone@outlook.com. All complaints will be reviewed and investigated promptly and fairly.

Project maintainers are obligated to maintain confidentiality with regard to the reporter of an incident.

## Attribution

This Code of Conduct is adapted from standard open source community guidelines.
